
def insertionSort(InputList):
    for i in range(1, len(InputList)):
        j = i-1
        nxt_element = InputList[i]
# Compare the current element with next one
		
        while (InputList[j] > nxt_element) and (j >= 0):
            InputList[j+1] = InputList[j]
            j=j-1
        InputList[j+1] = nxt_element
    return InputList


def bubbleSort(list):
        for iter_num in range(len(list)-1,0,-1):
            for idx in range(iter_num):
                if list[idx]>list[idx+1]:
                    temp = list[idx]
                    list[idx] = list[idx+1]
                    list[idx+1] = temp
        return list


def linearSearch(arr,x): 
    flag=0
    for i in range (0, len(arr)): 
        if (arr[i] == x): 
            
            print("{}found at position ={}",x,i+1) 
            flag=1
            return (i)
    if flag ==0 :
        print("{} is not found in the input",x) 
        return(-1)
         


def mergeSort(list):
    if len(list) <= 1:
        return list
# Find the middle point and devide it
    middle = len(list) // 2
    left_list = list[:middle]
    right_list = list[middle:]

    left_list = mergeSort(left_list)
    right_list = mergeSort(right_list)
    return merge(left_list, right_list)

# Merge the sorted halves
def merge(left_half,right_half):

    res = []
    while len(left_half) != 0 and len(right_half) != 0:
        if left_half[0] < right_half[0]:
            res.append(left_half[0])
            left_half.remove(left_half[0])
        else:
            res.append(right_half[0])
            right_half.remove(right_half[0])
    if len(left_half) == 0:
        res = res + right_half
    else:
        res = res + left_half
    return res




import setuptools
with open("README.md", "r") as fh:
    long_description = fh.read()
setuptools.setup(
     name='algorthm',  
     version='0.3',
     author="Dinak Lal",
     author_email="dinaklal@gmail.com",
     description="A package for studying various Algorithms and visualizing the operations ",
     long_description=long_description,
   long_description_content_type="text/markdown",
     url="https://github.com/dinaklal/algorthm",
     packages=setuptools.find_packages(),
     classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
     ], )



import sys


sys.path.append('../algorthm')

from algorthm.search.linearSearch import linearSearch


# arr = os.listdir()

# for item in arr :
#    if item.endswith(".py") and item != "__init__.py":
#       code = "from algorthm.sort."+str(item[:-3])+" import "+str(item[:-3])
#      print (code)
#     exec(code)

        
